=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2010-04-23 15:34:59 +0000
+++ drizzled/cursor.cc	2010-04-23 17:43:11 +0000
@@ -132,25 +132,25 @@
   return(doEndIndexScan());
 }
 
-int Cursor::ha_rnd_init(bool scan)
+int Cursor::startTableScan(bool scan)
 {
   int result;
   assert(inited==NONE || (inited==RND && scan));
-  inited= (result= rnd_init(scan)) ? NONE: RND;
+  inited= (result= doStartTableScan(scan)) ? NONE: RND;
 
   return result;
 }
 
-int Cursor::ha_rnd_end()
+int Cursor::endTableScan()
 {
   assert(inited==RND);
   inited=NONE;
-  return(rnd_end());
+  return(doEndTableScan());
 }
 
 int Cursor::ha_index_or_rnd_end()
 {
-  return inited == INDEX ? endIndexScan() : inited == RND ? ha_rnd_end() : 0;
+  return inited == INDEX ? endIndexScan() : inited == RND ? endTableScan() : 0;
 }
 
 void Cursor::ha_start_bulk_insert(ha_rows rows)
@@ -273,7 +273,7 @@
   position(record);
   if (inited && (error= endIndexScan()))
     return error;
-  if ((error= ha_rnd_init(false)))
+  if ((error= startTableScan(false)))
     return error;
 
   return rnd_pos(record, ref);
@@ -299,9 +299,9 @@
   if (stats.deleted < 10 || primary_key >= MAX_KEY ||
       !(table->index_flags(primary_key) & HA_READ_ORDER))
   {
-    (void) ha_rnd_init(1);
+    (void) startTableScan(1);
     while ((error= rnd_next(buf)) == HA_ERR_RECORD_DELETED) ;
-    (void) ha_rnd_end();
+    (void) endTableScan();
   }
   else
   {
@@ -1458,7 +1458,7 @@
               (unsigned char*) table->def_write_set.getBitmap());
   assert(table->s->all_set.isSetAll());
   assert(table->key_read == 0);
-  /* ensure that ha_index_end / ha_rnd_end has been called */
+  /* ensure that ha_index_end / endTableScan has been called */
   assert(inited == NONE);
   /* Free cache used by filesort */
   table->free_io_cache();

=== modified file 'drizzled/cursor.h'
--- drizzled/cursor.h	2010-04-23 15:36:57 +0000
+++ drizzled/cursor.h	2010-04-23 17:43:11 +0000
@@ -228,8 +228,8 @@
   int ha_open(Table *table, const char *name, int mode, int test_if_locked);
   int startIndexScan(uint32_t idx, bool sorted);
   int endIndexScan();
-  int ha_rnd_init(bool scan);
-  int ha_rnd_end();
+  int startTableScan(bool scan);
+  int endTableScan();
   int ha_reset();
 
   /* this is necessary in many places, e.g. in HANDLER command */
@@ -539,14 +539,14 @@
   { active_index= idx; return 0; }
   virtual int doEndIndexScan() { active_index= MAX_KEY; return 0; }
   /**
-    rnd_init() can be called two times without rnd_end() in between
+    doStartTableScan() can be called two times without doEndTableScan() in between
     (it only makes sense if scan=1).
     then the second call should prepare for the new table scan (e.g
     if rnd_init allocates the cursor, second call should position it
     to the start of the table, no need to deallocate and allocate it again
   */
-  virtual int rnd_init(bool scan)= 0;
-  virtual int rnd_end() { return 0; }
+  virtual int doStartTableScan(bool scan)= 0;
+  virtual int doEndTableScan() { return 0; }
   virtual int doInsertRecord(unsigned char *)
   {
     return HA_ERR_WRONG_COMMAND;

=== modified file 'drizzled/filesort.cc'
--- drizzled/filesort.cc	2010-03-23 10:05:10 +0000
+++ drizzled/filesort.cc	2010-04-23 17:43:11 +0000
@@ -507,7 +507,7 @@
   if (! indexfile && ! quick_select)
   {
     next_pos=(unsigned char*) 0;			/* Find records in sequence */
-    file->ha_rnd_init(1);
+    file->startTableScan(1);
     file->extra_opt(HA_EXTRA_CACHE,
 		    current_session->variables.read_buff_size);
   }
@@ -577,7 +577,7 @@
       if (!indexfile && !quick_select)
       {
         (void) file->extra(HA_EXTRA_NO_CACHE);
-        file->ha_rnd_end();
+        file->endTableScan();
       }
       return(HA_POS_ERROR);
     }
@@ -612,7 +612,7 @@
   {
     (void) file->extra(HA_EXTRA_NO_CACHE);	/* End cacheing of records */
     if (!next_pos)
-      file->ha_rnd_end();
+      file->endTableScan();
   }
 
   if (session->is_error())

=== modified file 'drizzled/item/subselect.cc'
--- drizzled/item/subselect.cc	2010-04-22 20:20:39 +0000
+++ drizzled/item/subselect.cc	2010-04-23 17:43:11 +0000
@@ -2280,7 +2280,7 @@
   if (table->cursor->inited)
     table->cursor->endIndexScan();
 
-  table->cursor->ha_rnd_init(1);
+  table->cursor->startTableScan(1);
   table->cursor->extra_opt(HA_EXTRA_CACHE,
                          current_session->variables.read_buff_size);
   table->null_row= 0;
@@ -2303,7 +2303,7 @@
     }
   }
 
-  table->cursor->ha_rnd_end();
+  table->cursor->endTableScan();
   return(error != 0);
 }
 

=== modified file 'drizzled/optimizer/quick_ror_intersect_select.cc'
--- drizzled/optimizer/quick_ror_intersect_select.cc	2010-04-19 19:23:14 +0000
+++ drizzled/optimizer/quick_ror_intersect_select.cc	2010-04-23 17:43:11 +0000
@@ -76,7 +76,7 @@
   alloc.free_root(MYF(0));
   if (need_to_fetch_row && head->cursor->inited != Cursor::NONE)
   {
-    head->cursor->ha_rnd_end();
+    head->cursor->endTableScan();
   }
   return;
 }
@@ -119,7 +119,7 @@
     ++it;
   }
 
-  if (need_to_fetch_row && head->cursor->ha_rnd_init(1))
+  if (need_to_fetch_row && head->cursor->startTableScan(1))
   {
     return 0;
   }

=== modified file 'drizzled/optimizer/quick_ror_union_select.cc'
--- drizzled/optimizer/quick_ror_union_select.cc	2010-04-19 19:23:14 +0000
+++ drizzled/optimizer/quick_ror_union_select.cc	2010-04-23 17:43:11 +0000
@@ -127,7 +127,7 @@
     queue->push(*it);
   }
 
-  if (head->cursor->ha_rnd_init(1))
+  if (head->cursor->startTableScan(1))
   {
     return 0;
   }
@@ -157,7 +157,7 @@
   quick_selects.clear();
   if (head->cursor->inited != Cursor::NONE)
   {
-    head->cursor->ha_rnd_end();
+    head->cursor->endTableScan();
   }
   alloc.free_root(MYF(0));
 }

=== modified file 'drizzled/records.cc'
--- drizzled/records.cc	2010-04-22 20:20:39 +0000
+++ drizzled/records.cc	2010-04-23 17:43:11 +0000
@@ -107,7 +107,7 @@
     reinit_io_cache(info->io_cache,internal::READ_CACHE,0L,0,0);
     info->ref_pos=table->cursor->ref;
     if (!table->cursor->inited)
-      table->cursor->ha_rnd_init(0);
+      table->cursor->startTableScan(0);
 
     /*
       table->sort.addon_field is checked because if we use addon fields,
@@ -139,7 +139,7 @@
   }
   else if (table->sort.record_pointers)
   {
-    table->cursor->ha_rnd_init(0);
+    table->cursor->startTableScan(0);
     info->cache_pos=table->sort.record_pointers;
     info->cache_end=info->cache_pos+
                     table->sort.found_records*info->ref_length;
@@ -149,7 +149,7 @@
   else
   {
     info->read_record= rr_sequential;
-    table->cursor->ha_rnd_init(1);
+    table->cursor->startTableScan(1);
     /* We can use record cache if we don't update dynamic length tables */
     if (!table->no_cache &&
         (use_record_cache > 0 ||

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2010-04-22 20:30:32 +0000
+++ drizzled/sql_select.cc	2010-04-23 17:43:11 +0000
@@ -3946,7 +3946,7 @@
 int init_read_record_seq(JoinTable *tab)
 {
   tab->read_record.read_record= rr_sequential;
-  if (tab->read_record.cursor->ha_rnd_init(1))
+  if (tab->read_record.cursor->startTableScan(1))
     return 1;
   return (*tab->read_record.read_record)(&tab->read_record);
 }
@@ -5327,7 +5327,7 @@
   org_record=(char*) (record=table->record[0])+offset;
   new_record=(char*) table->record[1]+offset;
 
-  cursor->ha_rnd_init(1);
+  cursor->startTableScan(1);
   error=cursor->rnd_next(record);
   for (;;)
   {
@@ -5448,7 +5448,7 @@
     return(1);
   }
 
-  cursor->ha_rnd_init(1);
+  cursor->startTableScan(1);
   key_pos= &key_buffer[0];
   for (;;)
   {
@@ -5496,14 +5496,14 @@
   free((char*) field_lengths);
   hash_free(&hash);
   cursor->extra(HA_EXTRA_NO_CACHE);
-  (void) cursor->ha_rnd_end();
+  (void) cursor->endTableScan();
   return(0);
 
 err:
   free((char*) field_lengths);
   hash_free(&hash);
   cursor->extra(HA_EXTRA_NO_CACHE);
-  (void) cursor->ha_rnd_end();
+  (void) cursor->endTableScan();
   if (error)
     table->print_error(error,MYF(0));
   return(1);

=== modified file 'plugin/archive/ha_archive.cc'
--- plugin/archive/ha_archive.cc	2010-04-22 20:20:39 +0000
+++ plugin/archive/ha_archive.cc	2010-04-23 17:43:11 +0000
@@ -756,7 +756,7 @@
   *first_value= share->archive_write.auto_increment + 1;
 }
 
-/* Initialized at each key walk (called multiple times unlike rnd_init()) */
+/* Initialized at each key walk (called multiple times unlike doStartTableScan()) */
 int ha_archive::doStartIndexScan(uint32_t keynr, bool)
 {
   active_index= keynr;
@@ -778,7 +778,7 @@
   current_key= key;
   current_key_len= key_len;
 
-  rc= rnd_init(true);
+  rc= doStartTableScan(true);
 
   if (rc)
     goto error;
@@ -822,7 +822,7 @@
   we assume the position will be set.
 */
 
-int ha_archive::rnd_init(bool scan)
+int ha_archive::doStartTableScan(bool scan)
 {
   if (share->crashed)
       return(HA_ERR_CRASHED_ON_USAGE);

=== modified file 'plugin/archive/ha_archive.h'
--- plugin/archive/ha_archive.h	2010-04-22 20:20:39 +0000
+++ plugin/archive/ha_archive.h	2010-04-23 17:43:11 +0000
@@ -102,7 +102,7 @@
   int doInsertRecord(unsigned char * buf);
   int real_write_row(unsigned char *buf, azio_stream *writer);
   int delete_all_rows();
-  int rnd_init(bool scan=1);
+  int doStartTableScan(bool scan=1);
   int rnd_next(unsigned char *buf);
   int rnd_pos(unsigned char * buf, unsigned char *pos);
   ArchiveShare *get_share(const char *table_name, int *rc);

=== modified file 'plugin/blackhole/ha_blackhole.cc'
--- plugin/blackhole/ha_blackhole.cc	2010-04-20 18:14:52 +0000
+++ plugin/blackhole/ha_blackhole.cc	2010-04-23 17:43:11 +0000
@@ -353,7 +353,7 @@
   return(table->next_number_field ? update_auto_increment() : 0);
 }
 
-int ha_blackhole::rnd_init(bool)
+int ha_blackhole::doStartTableScan(bool)
 {
   return(0);
 }

=== modified file 'plugin/blackhole/ha_blackhole.h'
--- plugin/blackhole/ha_blackhole.h	2010-04-20 18:14:52 +0000
+++ plugin/blackhole/ha_blackhole.h	2010-04-23 17:43:11 +0000
@@ -64,7 +64,7 @@
   int open(const char *name, int mode, uint32_t test_if_locked);
   int close(void);
   int doInsertRecord(unsigned char * buf);
-  int rnd_init(bool scan);
+  int doStartTableScan(bool scan);
   int rnd_next(unsigned char *buf);
   int rnd_pos(unsigned char * buf, unsigned char *pos);
   BlackholeShare *get_share(const char *table_name);

=== modified file 'plugin/csv/ha_tina.cc'
--- plugin/csv/ha_tina.cc	2010-04-20 19:05:03 +0000
+++ plugin/csv/ha_tina.cc	2010-04-23 17:43:11 +0000
@@ -1013,7 +1013,7 @@
   /*
     During update we mark each updating record as deleted
     (see the chain_append()) then write new one to the temporary data file.
-    At the end of the sequence in the rnd_end() we append all non-marked
+    At the end of the sequence in the doEndTableScan() we append all non-marked
     records from the data file to the temporary data file then rename it.
     The temp_file_length is used to calculate new data file length.
   */
@@ -1116,7 +1116,7 @@
 
 */
 
-int ha_tina::rnd_init(bool)
+int ha_tina::doStartTableScan(bool)
 {
   /* set buffer to the beginning of the file */
   if (share->crashed || init_data_file())
@@ -1231,7 +1231,7 @@
   slots to clean up all of the dead space we have collected while
   performing deletes/updates.
 */
-int ha_tina::rnd_end()
+int ha_tina::doEndTableScan()
 {
   char updated_fname[FN_REFLEN];
   off_t file_buffer_start= 0;

=== modified file 'plugin/csv/ha_tina.h'
--- plugin/csv/ha_tina.h	2010-04-20 19:05:03 +0000
+++ plugin/csv/ha_tina.h	2010-04-23 17:43:11 +0000
@@ -80,7 +80,7 @@
   drizzled::String buffer;
   /*
     The chain contains "holes" in the file, occured because of
-    deletes/updates. It is used in rnd_end() to get rid of them
+    deletes/updates. It is used in doEndTableScan() to get rid of them
     in the end of the query.
   */
   tina_set chain_buffer[DEFAULT_CHAIN_LENGTH];
@@ -129,10 +129,10 @@
   int doInsertRecord(unsigned char * buf);
   int doUpdateRecord(const unsigned char * old_data, unsigned char * new_data);
   int doDeleteRecord(const unsigned char * buf);
-  int rnd_init(bool scan=1);
+  int doStartTableScan(bool scan=1);
   int rnd_next(unsigned char *buf);
   int rnd_pos(unsigned char * buf, unsigned char *pos);
-  int rnd_end();
+  int doEndTableScan();
   TinaShare *get_share(const char *table_name);
   int free_share();
   int repair(drizzled::Session* session, drizzled::HA_CHECK_OPT* check_opt);

=== modified file 'plugin/embedded_innodb/embedded_innodb_engine.cc'
--- plugin/embedded_innodb/embedded_innodb_engine.cc	2010-04-22 20:20:39 +0000
+++ plugin/embedded_innodb/embedded_innodb_engine.cc	2010-04-23 17:43:11 +0000
@@ -1317,7 +1317,7 @@
   return err;
 }
 
-int EmbeddedInnoDBCursor::rnd_init(bool)
+int EmbeddedInnoDBCursor::doStartTableScan(bool)
 {
   ib_trx_t transaction= *get_trx(ha_session());
 
@@ -1387,7 +1387,7 @@
   return ret;
 }
 
-int EmbeddedInnoDBCursor::rnd_end()
+int EmbeddedInnoDBCursor::doEndTableScan()
 {
   ib_err_t err;
 
@@ -1685,7 +1685,7 @@
 {
   active_index= MAX_KEY;
 
-  return rnd_end();
+  return doEndTableScan();
 }
 
 int EmbeddedInnoDBCursor::index_prev(unsigned char *)

=== modified file 'plugin/embedded_innodb/embedded_innodb_engine.h'
--- plugin/embedded_innodb/embedded_innodb_engine.h	2010-04-22 20:20:39 +0000
+++ plugin/embedded_innodb/embedded_innodb_engine.h	2010-04-23 17:43:11 +0000
@@ -50,9 +50,9 @@
   int open(const char *name, int mode, uint32_t test_if_locked);
   int close(void);
   int doInsertRecord(unsigned char * buf);
-  int rnd_init(bool scan);
+  int doStartTableScan(bool scan);
   int rnd_next(unsigned char *buf);
-  int rnd_end();
+  int doEndTableScan();
   int rnd_pos(unsigned char * buf, unsigned char *pos);
 
   int doStartIndexScan(uint32_t, bool);

=== modified file 'plugin/function_engine/cursor.cc'
--- plugin/function_engine/cursor.cc	2010-03-31 05:53:34 +0000
+++ plugin/function_engine/cursor.cc	2010-04-23 17:43:11 +0000
@@ -60,7 +60,7 @@
   return 0;
 }
 
-int FunctionCursor::rnd_init(bool)
+int FunctionCursor::doStartTableScan(bool)
 {
   record_id= 0;
   rows_returned= 0;
@@ -109,7 +109,7 @@
   record_id++;
 }
 
-int FunctionCursor::rnd_end()
+int FunctionCursor::doEndTableScan()
 { 
   size_t length_of_vector= row_cache.size();
 

=== modified file 'plugin/function_engine/cursor.h'
--- plugin/function_engine/cursor.h	2010-03-30 00:17:03 +0000
+++ plugin/function_engine/cursor.h	2010-04-23 17:43:11 +0000
@@ -43,7 +43,7 @@
 
   int close(void);
 
-  int rnd_init(bool scan);
+  int doStartTableScan(bool scan);
 
   /* get the next row and copy it into buf */
   int rnd_next(unsigned char *buf);
@@ -51,7 +51,7 @@
   /* locate row pointed to by pos, copy it into buf */
   int rnd_pos(unsigned char *buf, unsigned char *pos);
 
-  int rnd_end();
+  int doEndTableScan();
 
   /* record position of a record for reordering */
   void position(const unsigned char *record);

=== modified file 'plugin/heap/ha_heap.cc'
--- plugin/heap/ha_heap.cc	2010-04-23 15:34:59 +0000
+++ plugin/heap/ha_heap.cc	2010-04-23 17:43:11 +0000
@@ -448,7 +448,7 @@
   return error;
 }
 
-int ha_heap::rnd_init(bool scan)
+int ha_heap::doStartTableScan(bool scan)
 {
   return scan ? heap_scan_init(file) : 0;
 }

=== modified file 'plugin/heap/ha_heap.h'
--- plugin/heap/ha_heap.h	2010-04-20 19:05:03 +0000
+++ plugin/heap/ha_heap.h	2010-04-23 17:43:11 +0000
@@ -72,7 +72,7 @@
   int index_prev(unsigned char * buf);
   int index_first(unsigned char * buf);
   int index_last(unsigned char * buf);
-  int rnd_init(bool scan);
+  int doStartTableScan(bool scan);
   int rnd_next(unsigned char *buf);
   int rnd_pos(unsigned char * buf, unsigned char *pos);
   void position(const unsigned char *record);

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2010-04-22 20:30:32 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2010-04-23 17:43:11 +0000
@@ -1586,7 +1586,7 @@
                      value here because it doesn't matter if we return the
                      HA_DO_INDEX_COND_PUSHDOWN bit from those "early" calls */
   start_of_scan(0),
-  num_doInsertRecord(0)
+  num_write_row(0)
 {}
 
 /*********************************************************************//**
@@ -3860,7 +3860,7 @@
   if ((sql_command == SQLCOM_ALTER_TABLE
        || sql_command == SQLCOM_CREATE_INDEX
        || sql_command == SQLCOM_DROP_INDEX)
-      && num_doInsertRecord >= 10000) {
+      && num_write_row >= 10000) {
     /* ALTER TABLE is COMMITted at every 10000 copied rows.
     The IX table lock for the original table has to be re-issued.
     As this method will be called on a temporary table where the
@@ -3873,7 +3873,7 @@
     dict_table_t* src_table;
     enum lock_mode  mode;
 
-    num_doInsertRecord = 0;
+    num_write_row = 0;
 
     /* Commit the transaction.  This will release the table
     locks, so they have to be acquired again. */
@@ -3920,7 +3920,7 @@
     }
   }
 
-  num_doInsertRecord++;
+  num_write_row++;
 
   /* This is the case where the table has an auto-increment column */
   if (table->next_number_field && record == table->record[0]) {
@@ -4961,7 +4961,7 @@
 @return 0 or error number */
 UNIV_INTERN
 int
-ha_innobase::rnd_init(
+ha_innobase::doStartTableScan(
 /*==================*/
   bool  scan) /*!< in: TRUE if table/index scan FALSE otherwise */
 {
@@ -4993,7 +4993,7 @@
 @return 0 or error number */
 UNIV_INTERN
 int
-ha_innobase::rnd_end(void)
+ha_innobase::doEndTableScan(void)
 /*======================*/
 {
   return(doEndIndexScan());

=== modified file 'plugin/innobase/handler/ha_innodb.h'
--- plugin/innobase/handler/ha_innodb.h	2010-04-23 15:36:57 +0000
+++ plugin/innobase/handler/ha_innodb.h	2010-04-23 17:43:11 +0000
@@ -80,7 +80,7 @@
 	uint		last_match_mode;/* match mode of the latest search:
 					ROW_SEL_EXACT, ROW_SEL_EXACT_PREFIX,
 					or undefined */
-	uint		num_doInsertRecord;	/*!< number of doInsertRecord() calls */
+	uint		num_write_row;	/*!< number of doInsertRecord() calls */
 
 	UNIV_INTERN uint store_key_val_for_row(uint keynr, char* buff, 
                                    uint buff_len, const unsigned char* record);
@@ -150,8 +150,8 @@
 	UNIV_INTERN int index_first(unsigned char * buf);
 	UNIV_INTERN int index_last(unsigned char * buf);
 
-	UNIV_INTERN int rnd_init(bool scan);
-	UNIV_INTERN int rnd_end();
+	UNIV_INTERN int doStartTableScan(bool scan);
+	UNIV_INTERN int doEndTableScan();
 	UNIV_INTERN int rnd_next(unsigned char *buf);
 	UNIV_INTERN int rnd_pos(unsigned char * buf, unsigned char *pos);
 

=== modified file 'plugin/myisam/ha_myisam.cc'
--- plugin/myisam/ha_myisam.cc	2010-04-22 20:20:39 +0000
+++ plugin/myisam/ha_myisam.cc	2010-04-23 17:43:11 +0000
@@ -1170,7 +1170,7 @@
 }
 
 
-int ha_myisam::rnd_init(bool scan)
+int ha_myisam::doStartTableScan(bool scan)
 {
   if (scan)
     return mi_scan_init(file);

=== modified file 'plugin/myisam/ha_myisam.h'
--- plugin/myisam/ha_myisam.h	2010-04-22 20:20:39 +0000
+++ plugin/myisam/ha_myisam.h	2010-04-23 17:43:11 +0000
@@ -58,7 +58,7 @@
   int index_first(unsigned char * buf);
   int index_last(unsigned char * buf);
   int index_next_same(unsigned char *buf, const unsigned char *key, uint32_t keylen);
-  int rnd_init(bool scan);
+  int doStartTableScan(bool scan);
   int rnd_next(unsigned char *buf);
   int rnd_pos(unsigned char * buf, unsigned char *pos);
   void position(const unsigned char *record);

=== modified file 'plugin/pbxt/src/ha_pbxt.cc'
--- plugin/pbxt/src/ha_pbxt.cc	2010-04-22 20:20:39 +0000
+++ plugin/pbxt/src/ha_pbxt.cc	2010-04-23 17:43:11 +0000
@@ -3659,15 +3659,15 @@
  */
  
 /*
- * rnd_init() is called when the system wants the storage engine to do a table
+ * doStartTableScan() is called when the system wants the storage engine to do a table
  * scan.
  * See the example in the introduction at the top of this file to see when
- * rnd_init() is called.
+ * doStartTableScan() is called.
  *
  * Called from filesort.cc, records.cc, sql_handler.cc, sql_select.cc, sql_table.cc,
  * and sql_update.cc.
  */
-int ha_pbxt::rnd_init(bool scan)
+int ha_pbxt::doStartTableScan(bool scan)
 {
 	int			err = 0;
 	XTThreadPtr	thread = pb_open_tab->ot_thread;
@@ -3677,15 +3677,15 @@
 
 	/* Call xt_tab_seq_exit() to make sure the resources used by the previous
 	 * scan are freed. In particular make sure cache page ref count is decremented.
-	 * This is needed as rnd_init() can be called mulitple times w/o matching calls 
-	 * to rnd_end(). Our experience is that currently this is done in queries like:
+	 * This is needed as doStartTableScan() can be called mulitple times w/o matching calls 
+	 * to doEndTableScan(). Our experience is that currently this is done in queries like:
 	 *
 	 * SELECT t1.c1,t2.c1 FROM t1 LEFT JOIN t2 USING (c1);
 	 * UPDATE t1 LEFT JOIN t2 USING (c1) SET t1.c1 = t2.c1 WHERE t1.c1 = t2.c1;
 	 *
 	 * when scanning inner tables. It is important to understand that in such case
-	 * multiple calls to rnd_init() are not semantically equal to a new query. For
-	 * example we cannot make row locks permanent as we do in rnd_end(), as 
+	 * multiple calls to doStartTableScan() are not semantically equal to a new query. For
+	 * example we cannot make row locks permanent as we do in doEndTableScan(), as 
 	 * ha_pbxt::unlock_row still can be called.
 	 */
 	xt_tab_seq_exit(pb_open_tab);
@@ -3730,7 +3730,7 @@
 	return err;
 }
 
-int ha_pbxt::rnd_end()
+int ha_pbxt::doEndTableScan()
 {
 	XT_TRACE_METHOD();
 

=== modified file 'plugin/pbxt/src/ha_pbxt.h'
--- plugin/pbxt/src/ha_pbxt.h	2010-04-22 20:30:32 +0000
+++ plugin/pbxt/src/ha_pbxt.h	2010-04-23 17:43:11 +0000
@@ -268,8 +268,8 @@
 	int		index_read_last(byte * buf, const byte * key, uint key_len);
 
 	/* Sequential scan functions: */
-	int		rnd_init(bool scan);								//required
-	int		rnd_end();
+	int		doStartTableScan(bool scan);								//required
+	int		doEndTableScan();
 	int		rnd_next(byte *buf);								//required
 	int		rnd_pos(byte * buf, byte *pos);													 //required
 	void	position(const byte *record);			//required

=== modified file 'plugin/pbxt/src/ha_xtsys.cc'
--- plugin/pbxt/src/ha_xtsys.cc	2010-04-08 16:11:29 +0000
+++ plugin/pbxt/src/ha_xtsys.cc	2010-04-23 17:43:11 +0000
@@ -147,7 +147,7 @@
 	return err;
 }
 
-int ha_xtsys::rnd_init(bool XT_UNUSED(scan))
+int ha_xtsys::doStartTableScan(bool XT_UNUSED(scan))
 {
 	int err = 0;
 

=== modified file 'plugin/pbxt/src/ha_xtsys.h'
--- plugin/pbxt/src/ha_xtsys.h	2010-04-08 16:11:29 +0000
+++ plugin/pbxt/src/ha_xtsys.h	2010-04-23 17:43:11 +0000
@@ -85,7 +85,7 @@
 
 	int		open(const char *name, int mode, uint test_if_locked);
 	int		close(void);
-	int		rnd_init(bool scan);
+	int		doStartTableScan(bool scan);
 	int		rnd_next(byte *buf);
 	int		rnd_pos(byte * buf, byte *pos);
 	void	position(const byte *record);

=== modified file 'plugin/tableprototester/tableprototester.cc'
--- plugin/tableprototester/tableprototester.cc	2010-04-01 15:54:57 +0000
+++ plugin/tableprototester/tableprototester.cc	2010-04-23 17:43:11 +0000
@@ -192,12 +192,12 @@
   return("BTREE");
 }
 
-int TableProtoTesterCursor::write_row(unsigned char *)
+int TableProtoTesterCursor::doInsertRecord(unsigned char *)
 {
   return(table->next_number_field ? update_auto_increment() : 0);
 }
 
-int TableProtoTesterCursor::rnd_init(bool)
+int TableProtoTesterCursor::doStartTableScan(bool)
 {
   return(0);
 }

=== modified file 'plugin/tableprototester/tableprototester.h'
--- plugin/tableprototester/tableprototester.h	2010-03-30 00:17:03 +0000
+++ plugin/tableprototester/tableprototester.h	2010-04-23 17:43:11 +0000
@@ -36,8 +36,8 @@
   uint32_t index_flags(uint32_t inx) const;
   int open(const char *name, int mode, uint32_t test_if_locked);
   int close(void);
-  int write_row(unsigned char * buf);
-  int rnd_init(bool scan);
+  int doInsertRecord(unsigned char * buf);
+  int doStartTableScan(bool scan);
   int rnd_next(unsigned char *buf);
   int rnd_pos(unsigned char * buf, unsigned char *pos);
 

